@@ -26,6 +26,14 @@ pub mod callback_token_verification;
 pub use self::callback_token_verification::CallbackTokenVerification;
 pub mod callback_token_verification_request;
 pub use self::callback_token_verification_request::CallbackTokenVerificationRequest;
+pub mod camera;
+pub use self::camera::Camera;
+pub mod camera_request;
+pub use self::camera_request::CameraRequest;
+pub mod camera_source_type_enum;
+pub use self::camera_source_type_enum::CameraSourceTypeEnum;
+pub mod camera_type_enum;
+pub use self::camera_type_enum::CameraTypeEnum;
 pub mod command_enum;
 pub use self::command_enum::CommandEnum;
 pub mod create_ansible_facts_request;
@@ -118,6 +126,8 @@ pub mod paginated_alert_list;
 pub use self::paginated_alert_list::PaginatedAlertList;
 pub mod paginated_appliance_list;
 pub use self::paginated_appliance_list::PaginatedApplianceList;
+pub mod paginated_camera_list;
+pub use self::paginated_camera_list::PaginatedCameraList;
 pub mod paginated_device_calibration_list;
 pub use self::paginated_device_calibration_list::PaginatedDeviceCalibrationList;
 pub mod paginated_experiment_device_config_list;
@@ -138,6 +148,8 @@ pub mod paginated_print_nanny_plugin_event_list;
 pub use self::paginated_print_nanny_plugin_event_list::PaginatedPrintNannyPluginEventList;
 pub mod paginated_print_session_list;
 pub use self::paginated_print_session_list::PaginatedPrintSessionList;
+pub mod paginated_printer_controller_list;
+pub use self::paginated_printer_controller_list::PaginatedPrinterControllerList;
 pub mod paginated_printer_profile_list;
 pub use self::paginated_printer_profile_list::PaginatedPrinterProfileList;
 pub mod paginated_remote_command_event_list;
@@ -158,12 +170,16 @@ pub mod patched_alert_request;
 pub use self::patched_alert_request::PatchedAlertRequest;
 pub mod patched_appliance_request;
 pub use self::patched_appliance_request::PatchedApplianceRequest;
+pub mod patched_camera_request;
+pub use self::patched_camera_request::PatchedCameraRequest;
 pub mod patched_device_calibration_request;
 pub use self::patched_device_calibration_request::PatchedDeviceCalibrationRequest;
 pub mod patched_octo_print_device_request;
 pub use self::patched_octo_print_device_request::PatchedOctoPrintDeviceRequest;
 pub mod patched_print_session_request;
 pub use self::patched_print_session_request::PatchedPrintSessionRequest;
+pub mod patched_printer_controller_request;
+pub use self::patched_printer_controller_request::PatchedPrinterControllerRequest;
 pub mod patched_printer_profile_request;
 pub use self::patched_printer_profile_request::PatchedPrinterProfileRequest;
 pub mod patched_remote_control_command_request;
@@ -186,6 +202,10 @@ pub mod print_session;
 pub use self::print_session::PrintSession;
 pub mod print_session_request;
 pub use self::print_session_request::PrintSessionRequest;
+pub mod printer_controller;
+pub use self::printer_controller::PrinterController;
+pub mod printer_controller_request;
+pub use self::printer_controller_request::PrinterControllerRequest;
 pub mod printer_event;
 pub use self::printer_event::PrinterEvent;
 pub mod printer_event_request;
@@ -208,6 +228,8 @@ pub mod remote_control_command;
 pub use self::remote_control_command::RemoteControlCommand;
 pub mod remote_control_command_request;
 pub use self::remote_control_command_request::RemoteControlCommandRequest;
+pub mod software_enum;
+pub use self::software_enum::SoftwareEnum;
 pub mod telemetry_event;
 pub use self::telemetry_event::TelemetryEvent;
 pub mod telemetry_event_event_type_enum;
